==> documentation-library-1.22.0.tgz: package/lib/components/Radio/RadioButtonGroup.spec.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/extends"));

var _react = _interopRequireWildcard(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _RadioButton = require("./RadioButton");

var _setupEnvironment = _interopRequireDefault(require("../../helpers/setupEnvironment"));

var _jsxRuntime = require("react/jsx-runtime");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/* global expect */
describe('components', function () {
  describe('RadioButtonGroup', function () {
    describe('default', function () {
      var Component = _RadioButton.RadioButtonGroup;
      var setup = (0, _setupEnvironment["default"])(Component);
      test('should render without crashing', function () {
        // Given
        var props = {
          name: 'name'
        }; // When

        var component = /*#__PURE__*/(0, _jsxRuntime.jsx)(Component, (0, _extends2["default"])({}, props)); // Then

        var div = document.createElement('div');

        _reactDom["default"].render(component, div);

        _reactDom["default"].unmountComponentAtNode(div);
      });
      test('should NOT render null', function () {
        // Given
        var props = {
          name: 'name'
        }; // When

        var _setup = setup(props),
            container = _setup.container; // Then


        expect(container.innerHTML).toBeString();
        expect(container.innerHTML).not.toHaveLength(0);
      });
      test('should have propTypes and defaultProps ', function () {
        // Given
        var component = Component; // When
        // Then

        expect(component.hasOwnProperty('propTypes')).toBeTruthy();
        expect(component.hasOwnProperty('defaultProps')).toBeTruthy();
      });
      test('should have proper displayName attribute', function () {
        // Given
        // const props = {}
        // When
        var component = Component; // Then

        expect(component.displayName).toBeString();
        expect(component.displayName).not.toHaveLength(0);
        expect(component.displayName).toMatchSnapshot();
      });
      describe('forwardRef', function () {
        test('should have reference', function () {
          // Given
          var props = {};
          var ref = /*#__PURE__*/(0, _react.createRef)(); // When

          var component = /*#__PURE__*/(0, _jsxRuntime.jsx)(Component, (0, _extends2["default"])({}, props, {
            ref: ref
          }));
          var div = document.createElement('div');

          _reactDom["default"].render(component, div); // Then


          expect(ref.current).not.toBe(undefined);
          expect(ref.current.nodeName).toBe('DIV');
        });
        test('should have defined elementType reference', function () {
          // Given
          var props = {
            elementType: 'span'
          };
          var ref = /*#__PURE__*/(0, _react.createRef)(); // When

          var component = /*#__PURE__*/(0, _jsxRuntime.jsx)(Component, (0, _extends2["default"])({}, props, {
            ref: ref
          }));
          var div = document.createElement('div');

          _reactDom["default"].render(component, div); // Then


          expect(ref.current).not.toBe(undefined);
          expect(ref.current.nodeName).toBe('SPAN');
        });
      });
    });
  });
});

==> documentation-library-1.24.0.tgz: package/lib/components/Radio/RadioButtonGroup.spec.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/extends"));
var _react = _interopRequireWildcard(require("react"));
var _reactDom = _interopRequireDefault(require("react-dom"));
var _RadioButton = require("./RadioButton");
var _setupEnvironment = _interopRequireDefault(require("../../helpers/setupEnvironment"));
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
/* global expect */

describe('components', function () {
  describe('RadioButtonGroup', function () {
    describe('default', function () {
      var Component = _RadioButton.RadioButtonGroup;
      var setup = (0, _setupEnvironment.default)(Component);
      test('should render without crashing', function () {
        // Given
        var props = {
          name: 'name'
        };

        // When
        var component = /*#__PURE__*/(0, _jsxRuntime.jsx)(Component, (0, _extends2.default)({}, props));

        // Then
        var div = document.createElement('div');
        _reactDom.default.render(component, div);
        _reactDom.default.unmountComponentAtNode(div);
      });
      test('should NOT render null', function () {
        // Given
        var props = {
          name: 'name'
        };

        // When
        var _setup = setup(props),
          container = _setup.container;

        // Then
        expect(container.innerHTML).toBeString();
        expect(container.innerHTML).not.toHaveLength(0);
      });
      test('should have propTypes and defaultProps ', function () {
        // Given
        var component = Component;

        // When

        // Then
        expect(component.hasOwnProperty('propTypes')).toBeTruthy();
        expect(component.hasOwnProperty('defaultProps')).toBeTruthy();
      });
      test('should have proper displayName attribute', function () {
        // Given
        // const props = {}

        // When
        var component = Component;

        // Then
        expect(component.displayName).toBeString();
        expect(component.displayName).not.toHaveLength(0);
        expect(component.displayName).toMatchSnapshot();
      });
      describe('forwardRef', function () {
        test('should have reference', function () {
          // Given
          var props = {};
          var ref = /*#__PURE__*/(0, _react.createRef)();

          // When
          var component = /*#__PURE__*/(0, _jsxRuntime.jsx)(Component, (0, _extends2.default)({}, props, {
            ref: ref
          }));
          var div = document.createElement('div');
          _reactDom.default.render(component, div);

          // Then
          expect(ref.current).not.toBe(undefined);
          expect(ref.current.nodeName).toBe('DIV');
        });
        test('should have defined elementType reference', function () {
          // Given
          var props = {
            elementType: 'span'
          };
          var ref = /*#__PURE__*/(0, _react.createRef)();

          // When
          var component = /*#__PURE__*/(0, _jsxRuntime.jsx)(Component, (0, _extends2.default)({}, props, {
            ref: ref
          }));
          var div = document.createElement('div');
          _reactDom.default.render(component, div);

          // Then
          expect(ref.current).not.toBe(undefined);
          expect(ref.current.nodeName).toBe('SPAN');
        });
      });
    });
  });
});
